% This file is part of the OPTPDE problem collection
%                 http://www.optpde.net
% It is provided as is, without any warranty, under the 
%
% Creative Commons Attribution-NonCommercial ShareAlike 4.0 International
%
%         http://creativecommons.org/licenses/by-nc-sa/4.0/
%
% Please give proper credits when using this file by referencing the 
% collection. For this purpose detailed bibliography data is 
% available at the collections website 
%                  
%                 http://www.optpde.net
%
% This file contains data for the benchmark problem 
%                      ccparfin1
% from  2022-04-01 


% setup the problem
problem = setup_problem;

% generate a grid on the time-space domain
[x1,x2] = meshgrid(linspace(0,pi,41),linspace(0,pi,41));
t = linspace(0,problem.T,101);

% plot the initial state
figure(1); clf; hold on
val = y0(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('initial state y_0');
view(3);

% plot the desired state at time T
figure(2); clf; hold on
val = yQ(problem,x1,x2,problem.T);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('desired state y_Q at time %.2f',problem.T));
view(3);

% plot the weight of the terminal state
figure(3); clf; hold on
val = ay(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('weight of terminal state a_y');
view(3);

% plot the four control weights 
figure(4); clf; hold on
val = w1(problem,x1,x2) + w2(problem,x1,x2) + w3(problem,x1,x2) + w4(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('control weights w_1, w_2, w_3, w_4');
view(3);

% plot the four source term coefficients beta_i
figure(5); clf; hold on
val1 = beta1(problem,t);
val2 = beta2(problem,t);
val3 = beta3(problem,t);
val4 = beta4(problem,t);
plot(t,[val1; val2; val3; val4]);
xlabel('t');
title('source term coefficients \beta_1, \beta_2, \beta_3, \beta_4');

% plot the distributed source term at time T
figure(6); clf; hold on
val = d(problem,x1,x2,problem.T);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title(sprintf('distributed source term d at time %.2f',problem.T));
view(3);

